==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/tr.js <==
/**
 * Turkish
 */

$.Editable.LANGS['tr'] = {
  translation: {
    "Bold": "Kal\u0131n",
    "Italic": "\u0130talik",
    "Underline": "Alt\u0131 \u00e7izili",
    "Strikethrough": "\u00dcst\u00fc \u00e7izili",
    "Font Size": "Yaz\u0131tipi B\u00fcy\u00fckl\u00fc\u011f\u00fc",
    "Color": "Rengi",
    "Background Color": "Arkaplan rengi",
    "Text Color": "Yaz\u0131 rengi",
    "Format Block": "Bi\u00e7imler",
    "Normal": "Normal",
    "Paragraph": "Paragraf",
    "Code": "Kod",
    "Quote": "Al\u0131nt\u0131",
    "Heading 1": "Ba\u015fl\u0131k 1",
    "Heading 2": "Ba\u015fl\u0131k 2",
    "Heading 3": "Ba\u015fl\u0131k 3",
    "Heading 4": "Ba\u015fl\u0131k 4",
    "Heading 5": "Ba\u015fl\u0131k 5",
    "Heading 6": "Ba\u015fl\u0131k 6",
    "Alignment": "Hizalama",
    "Align Left": "Sola hizala",
    "Align Center": "Ortala",
    "Align Right": "Sa\u011fa hizala",
    "Justify": "\u0130ki yana yasla",
    "Numbered List": "S\u0131ral\u0131 liste",
    "Bulleted List": "S\u0131ras\u0131z liste",
    "Indent Less": "Girintiyi azalt",
    "Indent More": "Girintiyi art\u0131r",
    "Select All": "T\u00fcm\u00fcn\u00fc se\u00e7",
    "Insert Link": "Ba\u011flant\u0131 ekle",
    "Insert Image": "Resim ekle",
    "Insert Video": "Video ekle",
    "Undo": "Geri Al",
    "Redo": "Yinele",
    "Show HTML": "G\u00f6ster HTML",
    "Float Left": "Sol",
    "Float None": "Hi\u00e7biri",
    "Float Right": "Sa\u011f",
    "Replace Image": "Resim de\u011fi\u015ftirmek",
    "Remove Image": "Resim kald\u0131r",
    "Title": "Ba\u015fl\u0131k",
    "Insert image": "Resim ekle",
    "Drop image": "B\u0131rak resim",
    "or click": "ya da t\u0131klay\u0131n",
    "Enter URL": "URL'yi girin",
    "Please wait!": "L\u00fctfen bekleyin!",
    "Are you sure? Image will be deleted.": "Emin misin? Resim silinecektir.",
    "UNLINK": "Ba\u011flant\u0131y\u0131 kald\u0131r",
    "Open in new tab": "Yeni sekmede a\u00e7",
    "Type something": "Bir \u015fey yaz\u0131n",
    "Cancel": "\u0130ptal",
    "OK": "Tamam",
    "Manage images": "G\u00f6r\u00fcnt\u00fcleri y\u00f6netin",
    "Delete": "Silmek",
    "Font Family": "Yaz\u0131tipi Ailesi",
    "Insert Horizontal Line": "Yatay \u00e7izgi ekleme"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.4.tar.gz: django-froala-editor-0.8.4/froala_editor/static/froala_editor/js/langs/tr.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Turkish
 */

$.Editable.LANGS['tr'] = {
  translation: {
    "Bold": "Kal\u0131n",
    "Italic": "\u0130talik",
    "Underline": "Alt\u0131 \u00e7izili",
    "Strikethrough": "\u00dcst\u00fc \u00e7izili",
    "Font Size": "Yaz\u0131tipi B\u00fcy\u00fckl\u00fc\u011f\u00fc",
    "Color": "Rengi",
    "Background Color": "Arkaplan rengi",
    "Text Color": "Yaz\u0131 rengi",
    "Format Block": "Bi\u00e7imler",
    "Normal": "Normal",
    "Paragraph": "Paragraf",
    "Code": "Kod",
    "Quote": "Al\u0131nt\u0131",
    "Heading 1": "Ba\u015fl\u0131k 1",
    "Heading 2": "Ba\u015fl\u0131k 2",
    "Heading 3": "Ba\u015fl\u0131k 3",
    "Heading 4": "Ba\u015fl\u0131k 4",
    "Heading 5": "Ba\u015fl\u0131k 5",
    "Heading 6": "Ba\u015fl\u0131k 6",
    "Alignment": "Hizalama",
    "Align Left": "Sola hizala",
    "Align Center": "Ortala",
    "Align Right": "Sa\u011fa hizala",
    "Justify": "\u0130ki yana yasla",
    "Numbered List": "S\u0131ral\u0131 liste",
    "Bulleted List": "S\u0131ras\u0131z liste",
    "Indent Less": "Girintiyi azalt",
    "Indent More": "Girintiyi art\u0131r",
    "Select All": "T\u00fcm\u00fcn\u00fc se\u00e7",
    "Insert Link": "Ba\u011flant\u0131 ekle",
    "Insert Image": "Resim ekle",
    "Insert Video": "Video ekle",
    "Undo": "Geri Al",
    "Redo": "Yinele",
    "Show HTML": "G\u00f6ster HTML",
    "Float Left": "Sol",
    "Float None": "Hi\u00e7biri",
    "Float Right": "Sa\u011f",
    "Replace Image": "Resim de\u011fi\u015ftirmek",
    "Remove Image": "Resim kald\u0131r",
    "Title": "Ba\u015fl\u0131k",
    "Insert image": "Resim ekle",
    "Drop image": "B\u0131rak resim",
    "or click": "ya da t\u0131klay\u0131n",
    "Enter URL": "URL'yi girin",
    "Please wait!": "L\u00fctfen bekleyin!",
    "Are you sure? Image will be deleted.": "Emin misin? Resim silinecektir.",
    "UNLINK": "Ba\u011flant\u0131y\u0131 kald\u0131r",
    "Open in new tab": "Yeni sekmede a\u00e7",
    "Type something": "Bir \u015fey yaz\u0131n",
    "Cancel": "\u0130ptal",
    "OK": "Tamam",
    "Manage images": "G\u00f6r\u00fcnt\u00fcleri y\u00f6netin",
    "Delete": "Silmek",
    "Font Family": "Yaz\u0131tipi Ailesi",
    "Insert Horizontal Line": "Yatay \u00e7izgi ekleme",
    "Table": "Tablo",
    "Insert table": "Tablo ekle",
    "Cell": "H\u00fccre",
    "Row": "Sat\u0131r",
    "Column": "S\u00fctun",
    "Delete table": "Tabloyu sil",
    "Insert cell before": "\u00d6nce h\u00fccre ekler",
    "Insert cell after": "Sonra h\u00fccre ekler",
    "Delete cell": "H\u00fccreyi silmek",
    "Merge cells": "H\u00fccreleri birle\u015ftir",
    "Horizontal split": "Yatay b\u00f6l\u00fcnm\u00fc\u015f",
    "Vertical split": "Dikey  b\u00f6l\u00fcnm\u00fc\u015f",
    "Insert row above": "\u00d6ncesine yeni sat\u0131r ekle",
    "Insert row below": "Sonras\u0131na yeni sat\u0131r ekle",
    "Delete row": "Sat\u0131r\u0131 sil",
    "Insert column before": "\u00d6ncesine yeni s\u00fctun ekle",
    "Insert column after": "Sonras\u0131na yeni s\u00fctun ekle",
    "Delete column": "S\u00fctunu sil"
  },
  direction: "ltr"
};
